@@ -23,9 +23,9 @@ function(X, y, S, offset=NULL, method="reml", bscov="unstr", control=list()) {
   nm <- rownames(y)
   np <- colnames(X)
 #
-  # DATA AUGMENTATION
-  if(control$augment) {
-    augdata <- augment(y,S,augvar=control$augvar)
+  # MSSING REPLACEMENT THROUGH DATA AUGMENTATION
+  if(control$inputna) {
+    augdata <- inputna(y,S,inputvar=control$inputvar)
     y <- augdata[,seq(k)]
     S <- augdata[,-seq(k)]
     nay[nay] <- FALSE
